#!/bin/bash
FRITZADDR=192.168.1.1
FRITZPASS=admin

# Installation:
#    1. Change address and password above
#    2. #ln -s /etc/munin/plugins/fritzbox ~/fritz.sh
#    3. #ln -s /etc/munin/plugins/fritzbox_roc ~/fritz.sh
#    4. service munin-node restart

# Check for rate-of-change mode
IS_ROC_MODE=0
echo "$0" | grep roc > /dev/null
if [ $? -eq 0 ] ; then
	IS_ROC_MODE=1
fi

# Display munin description for a field
function mundesc {
	echo $1.label $2
	if [ $IS_ROC_MODE -eq 1 ] ; then
		echo $1.type COUNTER
		echo $1.min 0
	fi
}

# Munin plugin names
if [ "$1" == "config" ] ; then

	if [ $IS_ROC_MODE -eq 0 ] ; then
		echo graph_title FritzBox stats
		echo graph_vlabel Quantity
	else 
		echo graph_title FritzBox stats \(5-min rate of change\)
		echo graph_vlabel Quantity/sec
	fi

	echo graph_args --base 1024 -l 0
	echo graph_category custom
	
	mundesc ipf_packets "iptables FORWARDED packets"
	mundesc ipf_data "iptables FORWARDED data"
	mundesc vdsl_rx "vdsl rx"
	mundesc vdsl_tx "vdsl tx"
	mundesc dsl_rx "dsl rx"
	mundesc dsl_tx "dsl tx"
	mundesc eth0_rx "eth0 rx"
	mundesc eth0_tx "eth0 tx"
	mundesc lan_rx "lan rx"
	mundesc lan_tx "lan tx"
	
	exit 0
fi

# Run a command remotely
function fritzcmd {
	expect - 2>/dev/null <<EOF
		log_user 0
		spawn telnet $FRITZADDR
		expect "web password:"
		send "$FRITZPASS\n"
		expect "#"
		send "$1\n"
		log_user 1
		expect "#"
EOF
}

# Format an ifconfig row munin-style
function iftofield {
	echo "$FRITZIF" | \
		grep -A 15 "$1" | grep -m 1 bytes | \
		sed -r "s/.*bytes:([0-9]*).*bytes:([0-9]*).*/$1_rx.value \1\n$1_tx.value \2/"
}

# Retrieve data for munin

fritzcmd "iptables -L -v -n -x" | grep FORWARD | \
	sed -r "s/.*ACCEPT ([0-9]*) packets, ([0-9]*).*/ipf_packets.value \1\nipf_data.value \2/"

FRITZIF=`fritzcmd "ifconfig"`
iftofield "vdsl"
iftofield "dsl"
iftofield "eth0"
iftofield "lan"
